##  Business Application
The business application subtype is used to distinguish logical applications from microservices and AI agents. Use this subtype to model applications and connect the microservice and AI agent subtypes to the business layer of the meta model. This allows you to show how microservices and AI agents indirectly support business capabilities.
